<template>
    <div>
        <el-dialog
            title="查看病害"
            v-if="dialogVisible"
            :visible.sync="dialogVisible"
            width="1200px"
            appendToBody
            :close-on-click-modal="false"
            top="8vh"
            @close="closeDialog"
        >
            <span slot="footer" class="dialog-footer">
                <el-button @click="closeDialog" size="medium">关闭</el-button>
            </span>
            <ht-table
                ref="htTable"
                quick-search-props="roadName"
                :data="data"
                :pageResult="pageResult"
                :selection="true"
                :show-export="false"
                :show-custom-column="false"
                :default-querys="defaultQuerys"
                @load="loadData"
            >
                <template v-slot:toolbar>
                    <export-data
                        tempFiles="病害信息导出模板"
                        bizCode="virusManagement"
                        :dataBaseOptions="dataBaseOptions"
                        :originAPIOptions="originAPIOptions"
                        :exportQuery="exportQuery"
                    ></export-data>
                </template>
                <template>
                    <ht-table-column
                        prop="subjectName"
                        label="病害类别"
                        :sortable="true"
                        :show-overflow-tooltip="true"
                    >
                    </ht-table-column>
                    <ht-table-column
                        prop="dsubjectName"
                        label="病害细目"
                        :sortable="true"
                        :show-overflow-tooltip="true"
                    >
                    </ht-table-column>
                    <ht-table-column
                        prop="roadName"
                        label="路段名称"
                        :sortable="true"
                        :show-overflow-tooltip="true"
                    >
                    </ht-table-column>
                    <ht-table-column
                        prop="type"
                        label="检查类别"
                        :filters="getDictData('xjlb')"
                        :show-overflow-tooltip="true"
                    >
                        <template v-slot="{row}">
                            <el-tag>{{ getDictName('xjlb', row.type) }}</el-tag>
                        </template>
                    </ht-table-column>

                    <ht-table-column
                        prop="direction"
                        label="方向"
                        :filters="getDictData('qlfx')"
                        :show-overflow-tooltip="true"
                    >
                        <template v-slot="{row}">
                            <el-tag>{{ getDictName('qlfx', row.direction) }}</el-tag>
                        </template>
                    </ht-table-column>

                    <ht-table-column
                        prop="positionName"
                        label="病害部位"
                        :sortable="true"
                        :show-overflow-tooltip="true"
                    >
                    </ht-table-column>
                    <ht-table-column
                        prop="description"
                        label="病害描述"
                        :sortable="true"
                        :show-overflow-tooltip="true"
                    >
                    </ht-table-column>
                    <ht-table-column
                        prop="handlingSituation"
                        label="处理情况"
                        :sortable="true"
                        :show-overflow-tooltip="true"
                    >
                    </ht-table-column>
                    <ht-table-column label="操作" width="170">
                        <template v-slot="{row}">
                            <el-dropdown
                                size="mini"
                                split-button
                                @command="handleCommand"
                                @click="handleCommand({row, command: 'Fillin'})"
                            >
                                <span>
                                    <i class="el-icon-view" style="margin-right: 5px"></i
                                    >查看病害图片</span
                                >
                                <el-dropdown-menu slot="dropdown">
                                    <el-dropdown-item
                                        icon="el-icon-tickets"
                                        :command="{
                                            row: row,
                                            command: 'workOrder',
                                        }"
                                        >发起养护工单</el-dropdown-item
                                    >
                                </el-dropdown-menu>
                            </el-dropdown>
                        </template>
                    </ht-table-column>
                </template>
            </ht-table>
            <image-dialog ref="image"></image-dialog>
        </el-dialog>
        <el-dialog
            custom-class="flowDialog"
            append-to-body
            title="发起养护工单"
            width="100%"
            fullscreen
            :visible.sync="flowDialogVisible"
            :before-close="handleCloseWorkOrder"
        >
            <startFlow
                :relationData="relationData"
                :defId="defId"
                :leaderId="0"
                @closeTaskFlow="handleCloseWorkOrder"
            ></startFlow>
        </el-dialog>
    </div>
</template>

<script>
import ImageDialog from '@/components/dialog/ImageDialog.vue'
import startFlow from '@/components/flow/taskFlowComponents/startFlow.vue'
export default {
    name: 'checkVirus',
    components: {
        ImageDialog,
        startFlow,
    },
    data() {
        return {
            dialogVisible: false,
            flowDialogVisible: false,
            dataBaseOptions: {
                dataBaseId: '',
                tableName: 'biz_disease', // 必填
                tableSchema: '',
            },
            originAPIOptions: {
                url: '/disease/v1/getJson', // 列表请求接口地址
                method: 'post', // 列表请求方法
                moduleRoot: 'yhxt', // 微服务根路径
            },
            exportQuery: {},
            data: [],
            pageResult: {
                page: 1,
                pageSize: 20,
                total: 0,
            },
            defaultQuerys: [{property: 'relevanceId', value: ''}],
            defId: '1434715043114651648',
            relationData: {},
        }
    },
    methods: {
        handleCloseWorkOrder() {
            this.flowDialogVisible = false
        },
        handleCommand(params) {
            console.log(params)
            if (params.command == 'Fillin') {
                this.seeImage(params.row)
            } else if (params.command == 'workOrder') {
                this.relationData = params.row
                this.flowDialogVisible = true
            }
        },
        seeImage(row) {
            this.$refs.image.open(row)
        },
        open(row) {
            this.dialogVisible = true
            this.defaultQuerys[0].value = row.id
        },
        closeDialog() {
            this.dialogVisible = false
        },
        loadData(param, cb) {
            this.exportQuery = param
            this.$http
                .post('${form}/disease/v1/getJson', param)
                .then(
                    (resp) => {
                        let res = resp.data.rows
                        this.data = res.filter((item) => item.temporary == 0)
                        this.pageResult = {
                            page: resp.data.page,
                            pageSize: resp.data.pageSize,
                            total: this.data.length,
                        }
                    },
                    (error) => {
                        reject(error)
                    }
                )
                .finally(() => {
                    if (cb) {
                        cb()
                    }
                })
        },
    },
}
</script>

<style lang="scss" scoped>
/deep/ .el-dialog__body {
    padding: 20px;
}
</style>